@@ -20,6 +20,7 @@
 # along with Ubiquity.  If not, see <http://www.gnu.org/licenses/>.
 
 from ubiquity.plugin import *
+from ubiquity import misc
 from mythbuntu_common.dictionaries import get_graphics_dictionary
 from mythbuntu_common.installer import *
 from ubiquity import install_misc
@@ -34,7 +35,8 @@ class PageGtk(MythPageGtk):
     plugin_title = 'ubiquity/text/driver_heading_label'
 
     def __init__(self, controller, *args, **kwargs):
-        self.drivers = get_graphics_dictionary()
+        with misc.raised_privileges():
+            self.drivers = get_graphics_dictionary()
         if len(self.drivers) > 0:
             self.ui_file = 'mythbuntu_stepDrivers'
             MythPageGtk.__init__(self, controller, *args, **kwargs)
